@@ -20,15 +20,15 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.1.8);
+  our $VERSION = qv(8.1.9);
   XSLoader::load("sealed", $VERSION);
 }
 
 my %valid_attrs                  = (sealed => 1);
-my $p_obj                        = B::svref_2object(sub {&tweak});
+my $p_obj                        = B::svref_2object(sub {&tweak}); # template sub
 
 # B::PADOP (w/ ithreads) or B::SVOP
-my $gv_op                        = $p_obj->START->next->next;
+my $gv_op                        = $p_obj->START->next->next; # its op of interest
 
 sub tweak :prototype($\@\@\@$$\%) {
   my ($op, $lexical_varnames, $pads, $op_stack, $cv_obj, $pad_names, $processed_op) = @_;
@@ -262,6 +262,7 @@ sub filter {
 
   return $status;
 }
+
 1;
 
 __END__
